from setuptools import setup

setup(name='class_filess',
      version='0.4',
      description='Удобный класс для работы с файлами',
      packages=['class_filess'],
      author_email='masha22340@gmail.com',
      zip_safe=False)